#############################################################################################
#   Version 8.42
#   
#   File: ixTclHalMsd.tcl
#
#  Package initialization file
#
#  This file is executed when you use "package require msd" to
#  load the IxTclHal library package.  It sets up the IXTCLHAL_LIBRARY
#  environment variable to point to the directory where the package
#  resides.
#
#  If the package is being loaded from a multi-user template script, then continue
#  otherwise return rightaway
#
#   Copyright ©  IXIA.
#	All Rights Reserved.
#
#############################################################################################

## basically this is a keeping room for all the method pointer stuff + ixTclHal package req procs

package req IxTclHal

set ixMsdCmds { msd }

if {$tcl_platform(platform) == "windows"} \
{
    load IxTclHal.dll Msd
} else \
{
    # This extracts the absolute path of this script. Its purpose is to differentiate between native                                                                                                 
    # IxTCLHAL package under Unix and platform independent TCL (the TCL client which communicates with TCLServer)                                                                                    
    set absolutePath    [ dict get [ info frame [ info frame ] ] file ]                                                                                                                              
    # Denotes support for IxTCLHAL package under Unix (search for the install path)                                                                                                                  
    set installLocation [file normalize /opt/ixia/ixos/]
    set nativeTCLUnix   [string match *$installLocation/* $absolutePath]

    # Try to see if we are in dev environment. If so, mark it appropriately                                                                                                                          
    # In order to work from your dev machine, you can set this variable before starting tclsh:                                                                                                       
    # export IXIA_TCL_DEV=1 (for example)                                                                                                                                                            
    if {[info exists ::env(IXIA_TCL_DEV)]} {                                                                                                                                                         
        set nativeTCLUnix 1                                                                                                                                                                          
    }                                                                                                                                                                                                

    # Load the Unix IxTCLHAL library                                                                                                                                                                 
    if {$nativeTCLUnix == 1} {                                                                                                                                                                       
        set ixtcl10Folder [string range $absolutePath 0 [string last / $absolutePath]]                                                                                                               
        load "$ixtcl10Folder../../../libixtclhal.so" Msd
    } else {
        # IxOS PIT 
        if {[tclServer::isTclServerConnected]} {
            # intercept ixTclServices commands, send to remote side for execution:
            remoteDefine $ixMsdCmds
            # Make sure the remote end knows what to do with those commands:
            if [catch {clientSend $ixTclSvrHandle "package req Msd"} result] {
                puts "Error installing Msd on remote end: "
                puts $result
                return 1
            }
        } else {
            puts "Error installing Msd on remote end, must be connected to ixTclServer."
            return 1
        }
    }
}

package provide Msd 8.42

ixTclHal::createCommand TCLMsd msd
#ixTclHal::createCommandPtr TCLMsd msd
